==> openshift-model-hive-5.12.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterRelocateBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterRelocateBuilder extends io.fabric8.openshift.api.model.hive.v1.ClusterRelocateFluentImpl<io.fabric8.openshift.api.model.hive.v1.ClusterRelocateBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.ClusterRelocate,io.fabric8.openshift.api.model.hive.v1.ClusterRelocateBuilder>{
  public ClusterRelocateBuilder() {
    this(false);
  }
  public ClusterRelocateBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterRelocate(), validationEnabled);
  }
  public ClusterRelocateBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterRelocateFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterRelocateBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterRelocateFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterRelocate(), validationEnabled);
  }
  public ClusterRelocateBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterRelocateFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterRelocate instance) {
    this(fluent, instance, false);
  }
  public ClusterRelocateBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterRelocateFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterRelocate instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterRelocateBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterRelocate instance) {
    this(instance,false);
  }
  public ClusterRelocateBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterRelocate instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.ClusterRelocateFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.ClusterRelocate build() {
    ClusterRelocate buildable = new ClusterRelocate(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterRelocateBuilder that = (ClusterRelocateBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.4.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterRelocateBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterRelocateBuilder extends ClusterRelocateFluentImpl<ClusterRelocateBuilder> implements VisitableBuilder<ClusterRelocate,ClusterRelocateBuilder>{
  public ClusterRelocateBuilder() {
    this(false);
  }
  public ClusterRelocateBuilder(Boolean validationEnabled) {
    this(new ClusterRelocate(), validationEnabled);
  }
  public ClusterRelocateBuilder(ClusterRelocateFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterRelocateBuilder(ClusterRelocateFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterRelocate(), validationEnabled);
  }
  public ClusterRelocateBuilder(ClusterRelocateFluent<?> fluent,ClusterRelocate instance) {
    this(fluent, instance, false);
  }
  public ClusterRelocateBuilder(ClusterRelocateFluent<?> fluent,ClusterRelocate instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterRelocateBuilder(ClusterRelocate instance) {
    this(instance,false);
  }
  public ClusterRelocateBuilder(ClusterRelocate instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ClusterRelocateFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterRelocate build() {
    ClusterRelocate buildable = new ClusterRelocate(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
